#!/usr/bin/env python

"""
Synopsis:
    Display weather downloaded from:
    http://wsf.cdyne.com/WeatherWS/Weather.asmx/GetCityForecastByZIP?ZIP=xxxxx
Usage:
    ./weather_test.py [ options ] <url | filename.xml>
Examples:
    ./weather_test.py weather_20150211.xml
    ./weather_test.py -o outdata.txt weather_20150211.xml
    ./weather_test.py -f -o outdata.txt weather_20150211.xml
    ./weather_test.py -f -o outdata.txt \
    http://wsf.cdyne.com/WeatherWS/Weather.asmx/GetCityForecastByZIP?ZIP=95817
"""

import sys
import os
import argparse
from lxml import objectify


def test(infilename, options, outfile=sys.stdout):
    doc = objectify.parse(infilename)
    root = doc.getroot()
    wrt = outfile.write
    show_weather(root, wrt)


def show_weather(weather, wrt):
    wrt('City:               {}\n'.format(weather.City.text))
    wrt('State:              {}\n'.format(weather.State.text))
    wrt('WeatherStationCity: {}\n'.format(weather.WeatherStationCity.text))
    tag = '{http://ws.cdyne.com/WeatherWS/}Forecast'
    for count, forecast in enumerate(
            weather.ForecastResult.iterchildren(tag=tag)):
        wrt('{}. Forecast\n'.format(count + 1))
        wrt('    Date/time:    {}\n'.format(forecast.Date))
        wrt('    WeatherID:    {}\n'.format(forecast.WeatherID))
        wrt('    Desciption:   {}\n'.format(forecast.Desciption))
        wrt('    Morning low:  {}\n'.format(forecast.Temperatures.MorningLow))
        wrt('    Daytime high: {}\n'.format(forecast.Temperatures.DaytimeHigh))
        wrt('    Nighttime probability of precipitation: {}\n'.format(
            forecast.ProbabilityOfPrecipiation.Nighttime))
        wrt('    Daytime probability of precipitation:   {}\n'.format(
            forecast.ProbabilityOfPrecipiation.Daytime))


def main():
    parser = argparse.ArgumentParser(
        description=__doc__,
        formatter_class=argparse.RawDescriptionHelpFormatter,)
    parser.add_argument(
        'location', type=str,
        help='url or filename to load and parse')
    parser.add_argument(
        '-o', '--outfile', type=str, default='',
        help='output file name')
    parser.add_argument(
        '-f', '--force', action='store_true', default=False,
        help='if True, overwrite output file.  default: False')
    options = parser.parse_args()
    if options.outfile:
        if not options.force and os.path.exists(options.outfile):
            parser.error('file exists.  use -f to overwrite.')
        with open(options.outfile, 'w') as outfile:
            test(options.location, options, outfile)
    else:
        test(options.location, options)


if __name__ == '__main__':
    main()
